Overview — django-guardian v1.0.0.beta1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »

# Overview

`django-guardian` is an implementation of object permissions for Django providing extra authentication backend.

## Features

- Object permissions for Django
- AnonymousUser support
- High level API
- Heavely tested
- Django’s admin integration
- Decorators

## Incoming

- Admin templates for grappelli

## Source and issue tracker

Sources are available at issue-tracker. You may also file a bug there.

## Alternate projects

Django 1.2 still has only foundation for object permissions [1] and `django-guardian` make use of new facilities and it is based on them. There are some other pluggable applications which does NOT require latest 1.2 version of Django. For instance, there are great django-authority or django-permissions available out there.

[1] | See http://docs.djangoproject.com/en/1.2/topics/auth/#handling-object-permissions for more detail.

### Navigation

- index
- modules |
- next |
- previous |
- django-guardian v1.0.0.beta1 documentation »